@@ -4,7 +4,7 @@ from b2luigi.basf2_helper.tasks import Basf2PathTask
 import example_mdst_analysis
 
 
-class MyAnalysisTask(Basf2PathTask):
+class AnalysisTask(Basf2PathTask):
     # set the batch_system property to use the gbasf2 wrapper batch process for this task
     batch_system = "gbasf2"
     # Must define a prefix for the gbasf2 project name to submit to the grid.
@@ -27,9 +27,9 @@ class MyAnalysisTask(Basf2PathTask):
         yield self.add_to_output("B_ntuple.root")
 
 
-class MasterTask(b2luigi.WrapperTask):
+class AnalysisWrapperTask(b2luigi.WrapperTask):
     """
-    We use the MasterTask to be able to require multiple analyse tasks with
+    We use the AnalysisWrapperTask to be able to require multiple analyse tasks with
     different input datasets and cut values. For each parameter combination, a
     different gbasf2 project will be submitted.
     """
@@ -41,7 +41,7 @@ class MasterTask(b2luigi.WrapperTask):
         # if you want to iterate over different cuts, just add more values to this list
         mbc_lower_cuts = [5.15, 5.2]
         for mbc_lower_cut in mbc_lower_cuts:
-            yield MyAnalysisTask(
+            yield AnalysisTask(
                 mbc_lower_cut=mbc_lower_cut,
                 gbasf2_project_name_prefix="luigiExample",
                 gbasf2_input_dataset=input_dataset,
@@ -50,6 +50,6 @@ class MasterTask(b2luigi.WrapperTask):
 
 
 if __name__ == '__main__':
-    main_task_instance = MasterTask()
+    main_task_instance = AnalysisWrapperTask()
     n_gbasf2_tasks = len(list(main_task_instance.requires()))
     b2luigi.process(main_task_instance, workers=n_gbasf2_tasks)
