@@ -23,10 +23,10 @@ class MyAdditionalTask(b2luigi.Task):
     @b2luigi.dispatch
     @b2luigi.on_temporary_files
     def run(self):
-        with open(self.get_output_file_name("combined.txt"), "w") as f:
+        with open(self.get_output_file_name("combined.txt"), "w"):
             os.kill(os.getpid(), 11)
 
 
 if __name__ == "__main__":
     b2luigi.set_setting("batch_system", "test")
-    b2luigi.process(MyAdditionalTask(some_parameter="bla_blub"), batch=True)
\ No newline at end of file
+    b2luigi.process(MyAdditionalTask(some_parameter="bla_blub"), batch=True)
